@@ -26,8 +26,9 @@ def test_symbols(config):
     config.update({'plugins': {'jedi_symbols': {'all_scopes': False}}})
     symbols = pyls_document_symbols(config, doc)
 
-    # All four symbols (import sys, a, B, main, y)
-    assert len(symbols) == 5
+    # All four symbols (import sys, a, B, main)
+    # y is not in the root scope, it shouldn't be returned
+    assert len(symbols) == 4
 
     def sym(name):
         return [s for s in symbols if s['name'] == name][0]
@@ -40,6 +41,10 @@ def test_symbols(config):
     # Not going to get too in-depth here else we're just testing Jedi
     assert sym('a')['location']['range']['start'] == {'line': 2, 'character': 0}
 
+    # Ensure that the symbol range spans the whole definition
+    assert sym('main')['location']['range']['start'] == {'line': 9, 'character': 0}
+    assert sym('main')['location']['range']['end'] == {'line': 12, 'character': 0}
+
 
 def test_symbols_all_scopes(config):
     doc = Document(DOC_URI, DOC)
